@@ -440,6 +440,21 @@ IMedia::ProgressResult Media::setLastTime( int64_t lastTime )
     return setLastPositionAndTime( positionType, position, lastTime );
 }
 
+
+bool Media::markAsPlayed()
+{
+    auto lastPlayedDate = time( nullptr );
+    const std::string req = "UPDATE " + Table::Name +
+            " SET last_played_date = ?, play_count = play_count + 1"
+            " WHERE id_media = ?";
+    if ( sqlite::Tools::executeUpdate( m_ml->getConn(), req, lastPlayedDate,
+                                       m_id ) == false )
+        return false;
+    m_lastPlayedDate = lastPlayedDate;
+    ++m_playCount;
+    return true;
+}
+
 bool Media::setPlayCount( uint32_t playCount )
 {
     static const std::string req = "UPDATE " + Media::Table::Name + " SET "
@@ -856,6 +871,9 @@ bool Media::markAsInternal( Type type, int64_t duration, int64_t deviceId, int64
                                        deviceId, folderId, ImportType::Internal,
                                        m_id ) == false )
         return false;
+    auto notifier = m_ml->getNotifier();
+    if ( notifier != nullptr )
+        notifier->notifyMediaCreation( shared_from_this() );
     m_type = type;
     m_duration = duration;
     m_deviceId = deviceId;
@@ -901,7 +919,7 @@ bool Media::convertToExternal()
     t->commit();
     auto notifier = m_ml->getNotifier();
     if ( notifier != nullptr )
-        notifier->notifyMediaConvertedToExternal( m_id );
+        notifier->notifyMediaRemoval( m_id );
     m_subType = IMedia::SubType::Unknown;
     m_importType = ImportType::External;
     m_deviceId = 0;
