@@ -46,6 +46,7 @@
 #include "MediaLibrary.h"
 #include "Label.h"
 #include "logging/Logger.h"
+#include "logging/IostreamLogger.h"
 #include "Movie.h"
 #include "parser/Parser.h"
 #include "Playlist.h"
@@ -130,6 +131,7 @@ const std::vector<const char*> MediaLibrary::SupportedMediaExtensions = {
     "alac",
     "amb",
     "amr",
+    "amrec",
     "amv",
     "aob",
     "ape",
@@ -319,7 +321,11 @@ MediaLibrary::MediaLibrary( const std::string& dbPath,
     , m_parser( this, &m_fsHolder )
     , m_discovererWorker( this, &m_fsHolder )
 {
-    Log::setLogLevel( LogLevel::Error );
+    if ( cfg != nullptr && cfg->logger != nullptr )
+        Log::SetLogger( cfg->logger );
+    else
+        Log::SetLogger( std::make_shared<IostreamLogger>() );
+    Log::setLogLevel( cfg != nullptr ? cfg->logLevel : LogLevel::Error );
     if ( cfg != nullptr )
     {
         for ( const auto& p : cfg->deviceListers )
@@ -2350,11 +2356,6 @@ const std::string& MediaLibrary::playlistPath() const
     return m_playlistPath;
 }
 
-void MediaLibrary::setLogger( ILogger* logger )
-{
-    Log::SetLogger( logger );
-}
-
 void MediaLibrary::startFsFactory( fs::IFileSystemFactory &fsFactory ) const
 {
     m_fsHolder.startFsFactory( fsFactory );
